@@ -71,25 +71,6 @@ malloc_debug(size_t size, char *filename, int linenum) {
     return ptr;
 }
 
-void *
-strdup_debug(const char *s, char *filename, int linenum) {
-    int i;
-    void *ptr;
-    ptr = strdup(s);
-//    fprintf(stderr, "strdup_debug: ptr=%p (%s,%d)\n", ptr, filename, linenum);
-    for (i=0 ; i < MALLOC_DEBUG_TABLE_NUM ; i++) {
-        if (malloc_debug_table[i].ptr == NULL) {
-            malloc_debug_table[i].ptr = ptr;
-            malloc_debug_table[i].filename = filename;
-            malloc_debug_table[i].linenum = linenum;
-//            fprintf(stderr, "(%d)\n", i);
-            return ptr;
-        }
-    }
-    fprintf(stderr, "strdup: table full... ;_;\n");
-    return ptr;
-}
-
 void
 free_debug(void *ptr, char *filename, int linenum) {
     int i;
