@@ -7,6 +7,7 @@
 #ifndef __SWF_OBJECT_H__
 #define __SWF_OBJECT_H__
 
+#include "y_keyvalue.h"
 #include "swf_header.h"
 #include "swf_header.h"
 #include "swf_tag.h"
@@ -82,8 +83,7 @@ extern int swf_object_replace_editstring(swf_object_t *swf,
                                          int initial_text_len);
 extern unsigned char *swf_object_get_actiondata(swf_object_t *swf, unsigned long *length, int tag_seqno);
 extern int swf_object_insert_action_setvariables(swf_object_t *swf,
-                                                 char **keys, char **values,
-                                                 int size);
+                                                 y_keyvalue_t *kv);
 
 
 extern int swf_object_apply_shapematrix_factor(swf_object_t *swf,int shape_id,
